==> teamapps-core-system-model-0.1-sources.jar: org/teamapps/model/controlcenter/OrganizationUnitViewQuery.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.record.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.enumeration.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.reference.value.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.query.*;
import org.teamapps.universaldb.context.*;

import java.util.*;
import java.util.function.Function;


public interface OrganizationUnitViewQuery extends Query<OrganizationUnitView> {

    static OrganizationUnitViewQuery create() {
        return new UdbOrganizationUnitViewQuery();
    }

    OrganizationUnitViewQuery id(Integer... ids);

    OrganizationUnitViewQuery id(BitSet ids);

    OrganizationUnitViewQuery id(Collection<Integer> ids);

    OrganizationUnitViewQuery fullTextFilter(TextFilter textFilter, String... fieldNames);

    OrganizationUnitViewQuery parseFullTextFilter(String query, String... fieldNames);

	OrganizationUnitViewQuery name(TranslatableTextFilter filter);

	OrganizationUnitViewQuery orName(TranslatableTextFilter filter);

	OrganizationUnitViewQuery filterParent(OrganizationUnitViewQuery query);

	OrganizationUnitViewQuery parent(NumericFilter filter);

	OrganizationUnitViewQuery orParent(NumericFilter filter);

	OrganizationUnitViewQuery filterChildren(OrganizationUnitViewQuery query);

	OrganizationUnitViewQuery children(MultiReferenceFilterType type, OrganizationUnitView ... value);

	OrganizationUnitViewQuery childrenCount(MultiReferenceFilterType type, int count);

	OrganizationUnitViewQuery children(MultiReferenceFilter filter);

	OrganizationUnitViewQuery orChildren(MultiReferenceFilter filter);

	OrganizationUnitViewQuery filterType(OrganizationUnitTypeViewQuery query);

	OrganizationUnitViewQuery type(NumericFilter filter);

	OrganizationUnitViewQuery orType(NumericFilter filter);

	OrganizationUnitViewQuery icon(TextFilter filter);

	OrganizationUnitViewQuery orIcon(TextFilter filter);

	OrganizationUnitViewQuery filterAddress(AddressViewQuery query);

	OrganizationUnitViewQuery address(NumericFilter filter);

	OrganizationUnitViewQuery orAddress(NumericFilter filter);


    OrganizationUnitViewQuery andOr(OrganizationUnitViewQuery... queries);

    OrganizationUnitViewQuery customFilter(Function<OrganizationUnitView, Boolean> customFilter);

}

==> teamapps-core-system-model-0.8-sources.jar: org/teamapps/model/controlcenter/OrganizationUnitViewQuery.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.record.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.enumeration.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.reference.value.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.query.*;
import org.teamapps.universaldb.context.*;

import java.util.*;
import java.util.function.Function;


public interface OrganizationUnitViewQuery extends Query<OrganizationUnitView> {

    static OrganizationUnitViewQuery create() {
        return new UdbOrganizationUnitViewQuery();
    }

    OrganizationUnitViewQuery id(Integer... ids);

    OrganizationUnitViewQuery id(BitSet ids);

    OrganizationUnitViewQuery id(Collection<Integer> ids);

    OrganizationUnitViewQuery fullTextFilter(TextFilter textFilter, String... fieldNames);

    OrganizationUnitViewQuery parseFullTextFilter(String query, String... fieldNames);

	OrganizationUnitViewQuery name(TranslatableTextFilter filter);

	OrganizationUnitViewQuery orName(TranslatableTextFilter filter);

	OrganizationUnitViewQuery filterParent(OrganizationUnitViewQuery query);

	OrganizationUnitViewQuery parent(NumericFilter filter);

	OrganizationUnitViewQuery orParent(NumericFilter filter);

	OrganizationUnitViewQuery filterChildren(OrganizationUnitViewQuery query);

	OrganizationUnitViewQuery children(MultiReferenceFilterType type, OrganizationUnitView ... value);

	OrganizationUnitViewQuery childrenCount(MultiReferenceFilterType type, int count);

	OrganizationUnitViewQuery children(MultiReferenceFilter filter);

	OrganizationUnitViewQuery orChildren(MultiReferenceFilter filter);

	OrganizationUnitViewQuery filterType(OrganizationUnitTypeViewQuery query);

	OrganizationUnitViewQuery type(NumericFilter filter);

	OrganizationUnitViewQuery orType(NumericFilter filter);

	OrganizationUnitViewQuery icon(TextFilter filter);

	OrganizationUnitViewQuery orIcon(TextFilter filter);

	OrganizationUnitViewQuery orgUnitLifeCycleStatus(EnumFilterType filterType, OrgUnitLifeCycleStatus ... enums);

	OrganizationUnitViewQuery orOrgUnitLifeCycleStatus(EnumFilterType filterType, OrgUnitLifeCycleStatus ... enums);

	OrganizationUnitViewQuery filterAddress(AddressViewQuery query);

	OrganizationUnitViewQuery address(NumericFilter filter);

	OrganizationUnitViewQuery orAddress(NumericFilter filter);


    OrganizationUnitViewQuery andOr(OrganizationUnitViewQuery... queries);

    OrganizationUnitViewQuery customFilter(Function<OrganizationUnitView, Boolean> customFilter);

}
